unit FmxBrowserFormUnit;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Graphics, FMX.Dialogs, FMX.Edit,
  FMX.Controls.Presentation, FMX.StdCtrls, FMX.Objects, FMX.Layouts,
  {$IFDEF MSWINDOWS}
  Vcl.Edge, Winapi.ActiveX, FMX.Platform.Win
  {$ELSE}
  FMX.WebBrowser
  {$ENDIF}
  ;

type
  TFmxBrowserForm = class(TForm)
    Layout1: TLayout;
    BrowserBase: TLayout;
    Rectangle1: TRectangle;
    Label1: TLabel;
    URLBox: TEdit;
    StatusBar1: TStatusBar;
    Label2: TLabel;
    SpeedButton1: TSpeedButton;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormResize(Sender: TObject);
  private
    {$IFDEF MSWINDOWS}
    FWebBrowser: TEdgeBrowser;
    {$ELSE}
    FWebBrowser: TWebBrowser;
    {$ENDIF}

    procedure SetWebBrowser;
    {$IFDEF MSWINDOWS}
    procedure OnNavigationCompleted(Sender: TCustomEdgeBrowser;
      IsSuccess: Boolean; WebErrorStatus: TOleEnum);
    {$ELSE}
    procedure OnDidFinishLoad(Sender: TObject);
    {$ENDIF}
  public
    procedure BrowserFormShow(Url: string; Hint: string);
  end;

var
  FmxBrowserForm: TFmxBrowserForm;

implementation

uses
  TTwitterBot2ClassUnit;

{$R *.fmx}

procedure TFmxBrowserForm.FormCreate(Sender: TObject);
begin
  SetWebBrowser;
end;

procedure TFmxBrowserForm.FormDestroy(Sender: TObject);
begin
  FWebBrowser.Free;
end;

procedure TFmxBrowserForm.FormResize(Sender: TObject);
begin
  {$IFDEF MSWINDOWS}
  FWebBrowser.BoundsRect := BrowserBase.BoundsRect.Round;
  {$ENDIF}
end;

procedure TFmxBrowserForm.SetWebBrowser;
begin
  {$IFDEF MSWINDOWS}
  FWebBrowser := TEdgeBrowser.Create(Self);
  FWebBrowser.ParentWindow := WindowHandleToPlatform(Self.Handle).Wnd;
  FWebBrowser.BoundsRect := BrowserBase.BoundsRect.Round;
  FWebBrowser.OnNavigationCompleted := OnNavigationCompleted;
  {$ELSE}
  FWebBrowser := TWebBrowser.Create(Self);
  FWebBrowser.Parent := BrowserBase;
  // FWebBrowser.BoundsRect := BrowserBase.BoundsRect;
  FWebBrowser.Align := TAlignLayout.Client;
  FWebBrowser.OnDidFinishLoad := OnDidFinishLoad;
  {$ENDIF}
end;

{$IFDEF MSWINDOWS}
procedure TFmxBrowserForm.OnNavigationCompleted(Sender: TCustomEdgeBrowser;
  IsSuccess: Boolean; WebErrorStatus: TOleEnum);
var
  DoCloseWebForm: boolean;
begin
  URLBox.Text := FWebBrowser.LocationURL;
  if Assigned(TwitterBot2) then begin
    TwitterBot2.BrowserUrlChanged(FWebBrowser.LocationURL, DoCloseWebForm);
    if DoCloseWebForm then
      Self.Close;
  end;
end;

{$ELSE}
procedure TFmxBrowserForm.OnDidFinishLoad(Sender: TObject);
var
  DoCloseWebForm: boolean;
begin
  URLBox.Text := FWebBrowser.URL;
  if Assigned(TwitterBot2) then begin
    TwitterBot2.BrowserUrlChanged(FWebBrowser.URL, DoCloseWebForm);
    if DoCloseWebForm then
      Self.Close;
  end;
end;
{$ENDIF}

procedure TFmxBrowserForm.BrowserFormShow(Url: string; Hint: string);
begin
  if not Url.IsEmpty then begin
    Self.Show;
    FWebBrowser.Navigate(Url);
    FWebBrowser.SetFocus;
  end else
    Self.Close;

  Label2.Text := Hint;
end;

end.
